@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -18,23 +18,22 @@
 */
 #include "sieveconditiontrue.h"
 #include "editor/sieveeditorutil.h"
+#include "libksieve_debug.h"
+#include "autocreatescripts/autocreatescriptutil_p.h"
+
 #include <KLocalizedString>
 
+#include <QXmlStreamReader>
 #include <QHBoxLayout>
 #include <QLabel>
 
 using namespace KSieveUi;
 
-SieveConditionTrue::SieveConditionTrue(QObject *parent)
-    : SieveCondition(QStringLiteral("true"), i18n("True"), parent)
+SieveConditionTrue::SieveConditionTrue(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("true"), i18n("True"), parent)
 {
 }
 
-SieveCondition *SieveConditionTrue::newAction()
-{
-    return new SieveConditionTrue;
-}
-
 QWidget *SieveConditionTrue::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -49,7 +48,7 @@ QWidget *SieveConditionTrue::createParamWidget(QWidget *parent) const
 
 QString SieveConditionTrue::code(QWidget *) const
 {
-    return QStringLiteral("true");
+    return QStringLiteral("true") + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
 QString SieveConditionTrue::help() const
@@ -57,9 +56,25 @@ QString SieveConditionTrue::help() const
     return i18n("The \"true\" test always evaluates to true.");
 }
 
-bool SieveConditionTrue::setParamWidgetValue(const QDomElement &, QWidget *, bool, QString &)
+bool SieveConditionTrue::setParamWidgetValue(QXmlStreamReader &element, QWidget *, bool, QString &error)
 {
-    //Nothing
+    QString commentStr;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("comment")) {
+            commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveConditionTrue::setParamWidgetValue unknown tagName " << tagName;
+        }
+    }
+    if (!commentStr.isEmpty()) {
+        setComment(commentStr);
+    }
+
     return true;
 }
 
