@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -57,7 +57,7 @@ QWidget *SieveConditionVirusTest::createParamWidget(QWidget *parent) const
     spinbox->setMaximum(5);
     spinbox->setMinimum(0);
     spinbox->setObjectName(QStringLiteral("value"));
-    connect(spinbox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SieveConditionVirusTest::valueChanged);
+    connect(spinbox, QOverload<int>::of(&QSpinBox::valueChanged), this, &SieveConditionVirusTest::valueChanged);
     lay->addWidget(spinbox);
     return w;
 }
