@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,13 +21,12 @@
 
 #include <KMessageWidget>
 
-namespace KSieveUi
-{
+namespace KSieveUi {
 class SieveEditorWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorWarning(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorWarning(QWidget *parent = nullptr);
     ~SieveEditorWarning();
 };
 }
